==> apache-camel-4.13.0-src.zip: apache-camel-4.13.0/components/camel-twilio/src/main/java/org/apache/camel/component/twilio/TwilioProducer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.twilio;

import java.util.Map;

import org.apache.camel.RuntimeCamelException;
import org.apache.camel.component.twilio.internal.TwilioApiName;
import org.apache.camel.component.twilio.internal.TwilioPropertiesHelper;
import org.apache.camel.support.component.AbstractApiProducer;
import org.apache.camel.support.component.ApiMethod;

/**
 * The Twilio producer.
 */
public class TwilioProducer extends AbstractApiProducer<TwilioApiName, TwilioConfiguration> {

    protected final TwilioEndpoint endpoint;

    public TwilioProducer(TwilioEndpoint endpoint) {
        super(endpoint, TwilioPropertiesHelper.getHelper(endpoint.getCamelContext()));
        this.endpoint = endpoint;
    }

    @Override
    protected Object doInvokeMethod(ApiMethod method, Map<String, Object> properties) throws RuntimeCamelException {
        Object executor = super.doInvokeMethod(method, properties);
        return endpoint.execute(executor, method, properties);
    }
}

==> apache-camel-4.17.0-src.zip: apache-camel-4.17.0/components/camel-twilio/src/main/java/org/apache/camel/component/twilio/TwilioProducer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.twilio;

import java.util.Map;

import org.apache.camel.RuntimeCamelException;
import org.apache.camel.component.twilio.internal.TwilioApiName;
import org.apache.camel.component.twilio.internal.TwilioPropertiesHelper;
import org.apache.camel.support.component.AbstractApiProducer;
import org.apache.camel.support.component.ApiMethod;

/**
 * The Twilio producer.
 */
public class TwilioProducer extends AbstractApiProducer<TwilioApiName, TwilioConfiguration> {

    protected final TwilioEndpoint endpoint;

    public TwilioProducer(TwilioEndpoint endpoint) {
        super(endpoint, TwilioPropertiesHelper.getHelper(endpoint.getCamelContext()));
        this.endpoint = endpoint;
    }

    @Override
    protected Object doInvokeMethod(ApiMethod method, Map<String, Object> properties)
            throws RuntimeCamelException {
        Object executor = super.doInvokeMethod(method, properties);
        return endpoint.execute(executor, method, properties);
    }
}
